@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2023 Red Hat, Inc.
+ * Copyright (c) 2012-2024 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -285,8 +285,7 @@ public class GithubApiClientTest {
 
   @Test(
       expectedExceptions = ScmCommunicationException.class,
-      expectedExceptionsMessageRegExp =
-          "Unexpected status code 502 \\(GET http://localhost:\\d*/api/v3/user\\) 502")
+      expectedExceptionsMessageRegExp = "Unexpected status code 502 item not found")
   public void shouldThrowExceptionOnOtherError() throws Exception {
     // given
     stubFor(
